@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -543,47 +543,33 @@ misc_scroll_window (GtkWidget  *widget,
                     const gint  height)
 {
   GdkGC *gc;
-  GdkRectangle rc;
 
   if (ABS (dx) > width || ABS (dy) > height)
     {
-      rc.x = x;
-      rc.y = y;
-      rc.width = width;
-      rc.height = height;
-      gtk_widget_draw (widget, &rc);
+      gtk_widget_queue_draw_area (widget, x, y, width, height);
     }
   else if (dx != 0 || dy != 0)
     {
       gc = gdk_gc_new (widget->window);
       gdk_gc_set_exposures (gc, TRUE);
-      gdk_window_copy_area (widget->window,
-                            gc,
-                            dx > 0 ? x + dx : x,
-                            dy > 0 ? y + dy : y,
-                            widget->window,
-                            dx > 0 ? x : x - dx,
-                            dy > 0 ? y : y - dy,
-                            width - ABS (dx),
-                            height - ABS (dy));
-      gdk_gc_destroy (gc);
+      gdk_draw_drawable  (widget->window,
+                          gc,
+                          widget->window,
+                          dx > 0 ? x : x - dx,
+                          dy > 0 ? y : y - dy,
+                          dx > 0 ? x + dx : x,
+                          dy > 0 ? y + dy : y,
+                          width - ABS (dx),
+                          height - ABS (dy));
+      g_object_unref (gc);
       if (dx != 0)
-        {
-          rc.x = dx > 0 ? x : x + width + dx;
-          rc.y = y;
-          rc.width = ABS (dx);
-          rc.height = height;
-          gtk_widget_draw (widget, &rc);
-        }
+        gtk_widget_queue_draw_area (widget, dx > 0 ? x : x + width + dx, y,
+                                                            ABS (dx), height);
       if (dy != 0)
-        {
-          rc.x = x;
-          rc.y = dy > 0 ? y : y + height + dy;
-          rc.width = width;
-          rc.height = ABS (dy);
-          gtk_widget_draw (widget, &rc);
-        }
+        gtk_widget_queue_draw_area (widget, x, dy > 0 ? y : y + height + dy,
+                                                            width, ABS (dy));
     }
+  gdk_window_process_updates (widget->window, TRUE);
 }
 
 
@@ -769,11 +755,7 @@ misc_str_from_float (const gint value,
     gchar *text = NULL;
     gint i = 0, n, t;
 
-#ifdef G_HAVE_GINT64
   n = t = (gint64)value * 100000 / divide;
-#else /* not G_HAVE_GINT64 */
-  n = t = value * 100000 / divide;
-#endif /* not G_HAVE_GINT64 */
   if (t == 0)
     {
       text = g_malloc (sizeof (gchar) * 4);
