@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __MISC_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 
 
 #ifdef __cplusplus
@@ -30,16 +30,23 @@ extern "C" {
 
 #define MISC_CREATE_MENU_BAR       1
 #define MISC_CREATE_MENU_SHELL     2
-#define MISC_CREATE_MENU_ITEM      3
-#define MISC_CREATE_MENU_SEPARATOR 4
+#define MISC_CREATE_MENU_SEPARATOR 3
+#define MISC_CREATE_MENU_STOCK     4
+#define MISC_CREATE_MENU_ITEM      5
+#define MISC_CREATE_MENU_CHECK     6
+#define MISC_CREATE_MENU_RADIO     7
 #define MISC_CREATE_MENU_TERMINAL  0
-
+#define MISC_CREATE_MENU_ELLIPSIS  8
+#define MISC_CREATE_MENU_NOIMAGE   16
+#define MISC_CREATE_MENU_DISABLE   32
+#define MISC_CREATE_MENU_MASK      7
 
 typedef struct _MiscCreateMenuEntry
 {
   gchar *path;
   gchar *name;
   gchar *accel;
+  const gchar **xpm;
   guint menu_type;
   void (*func) (GtkWidget *widget, gpointer user_data);
   gpointer user_data;
@@ -94,11 +101,41 @@ misc_find_toolbar (MiscCreateToolbarEntry *entries,
                    const gchar            *path);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:特定ファイル関数群                                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ユーザ設定ファイルを取得する
+    group,グループ
+     name,アプリケーション名
+     file,ファイル名
+      RET,ユーザ設定ファイル                                                */
+const gchar *
+misc_spec_config (const gchar *group,
+                  const gchar *name,
+                  const gchar *file);
+
+
+/*  ja:ロケールのディレクトリを取得する
+    prgname,プログラム
+        RET,ロケールのディレクトリ                                          */
+const gchar *
+misc_spec_locale (const gchar *prgname);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:低レベル関数群                                                           *
 *                                                                             *
 ******************************************************************************/
+/*  ja:mnemonicをテキストに変換する
+    mnemonic,mnemonic
+         RET,テキスト                                                       */
+gchar *
+misc_mnemonic_to_text (const gchar *mnemonic);
+
+
 /*  ja:スクロールバーを設定する
        scroll,スクロールウイジット
          func,シグナル関数
@@ -135,6 +172,13 @@ misc_scroll_window (GtkWidget  *widget,
                     const gint  height);
 
 
+/* ja:ESCが押されたとき */
+gboolean
+misc_dialog_key_press (GtkWidget   *widget,
+                       GdkEventKey *event,
+                       gpointer     user_data);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:数値文字列関数群                                                         *
