@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -497,7 +497,7 @@ file_open_edit (const gchar *file)
   page_num = orz_mdi_append_page (ORZ_MDI (mdi),
                                                 table, filename, !file, tmaid);
   gtk_widget_show_all (table);
-  gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
   gtk_widget_grab_focus (tmaid->drawing);
 
   /* ja:Input Method */
