@@ -43,10 +43,17 @@ repinfo_dialog (ReplaceInfo *ri)
                             (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
+                            _("_All Replace"), REPLACE_ALL,
+                            _("_Next"), REPLACE_NEXT,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             _("_Next"), REPLACE_NEXT,
                             _("_All Replace"), REPLACE_ALL,
                             GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
+#endif /* not G_OS_WIN32 */
                             NULL);
   g_free (title);
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
